@@ -1,13 +1,14 @@
 package ZeroMQ;
 use strict;
 BEGIN {
-    our $VERSION = '0.02_05';
+    our $VERSION = '0.09_01';
     our @ISA = qw(Exporter);
 }
 use ZeroMQ::Raw ();
 use ZeroMQ::Context;
 use ZeroMQ::Socket;
 use ZeroMQ::Message;
+use ZeroMQ::Poller;
 use ZeroMQ::Constants;
 use 5.008;
 use Carp ();
@@ -98,9 +99,33 @@ The C<ZeroMQ> module is a wrapper of the 0MQ message passing library for Perl.
 It's a thin wrapper around the C API. Please read L<http://zeromq.org> for
 more details on ZeroMQ.
 
+=head1 CLASS WALKTHROUGH
+
+=over 4
+
+=item ZeroMQ::Raw
+
+Use L<ZeroMQ::Raw> to get access to the C API such as C<zmq_init>, C<zmq_socket>, et al. Functions provided in this low level API should follow the C API exactly.
+
+=item ZeroMQ::Constants
+
+L<ZeroMQ::Constants> contains all of the constants that are known to be extractable from zmq.h. Do note that sometimes the list changes due to additions/deprecations in the underlying zeromq2 library. We try to do our best to make things available (at least to warn you that some symbols are deprecated), but it may not always be possible.
+
+=item ZeroMQ::Context
+
+=item ZeroMQ::Socket
+
+=item ZeroMQ::Message
+
+L<ZeroMQ::Context>, L<ZeroMQ::Socket>, L<ZeroMQ::Message> contain the high-level, more perl-ish interface to the zeromq functionalities.
+
+=item ZeroMQ
+
 Loading C<ZeroMQ> will make the L<ZeroMQ::Context>, L<ZeroMQ::Socket>, and 
 L<ZeroMQ::Message> classes available as well.
 
+=back
+
 =head1 BASIC USAGE
 
 To start using ZeroMQ, you need to create a context object, then as many ZeroMQ::Socket as you need:
@@ -178,8 +203,8 @@ your application, use a name that's different from 'json'.
 =head1 ASYNCHRONOUS I/O WITH ZEROMQ
 
 By default ZeroMQ comes with its own zmq_poll() mechanism that can handle
-non-blocking sockets. You can use this by creating calling zmq_poll with a list
-of hashrefs:
+non-blocking sockets. You can use this by calling zmq_poll with a list of
+hashrefs:
 
     zmq_poll([
         {
@@ -195,13 +220,17 @@ of hashrefs:
     ], $timeout );
 
 Unfortunately this custom polling scheme doesn't play too well with AnyEvent.
+
 As of zeromq2-2.1.0, you can use getsockopt to retrieve the underlying file
 descriptor, so use that to integrate ZeroMQ and AnyEvent:
 
+    my $socket = zmq_socket( $ctxt, ZMQ_REP );
     my $fh = zmq_getsockopt( $socket, ZMQ_FD );
     my $w; $w = AE::io $fh, 0, sub {
+        while ( my $msg = zmq_recv( $socket, ZMQ_RECVMORE ) ) {
+            # do something with $msg;
+        }
         undef $w;
-        print $fh "Hello\n";
     };
 
 =head1 NOTES ON MULTI-PROCESS and MULTI-THREADED USAGE
