@@ -7,7 +7,7 @@ BEGIN {
     # XXX it's a hassle, but keep it in sync with ZeroMQ.pm
     # by loading this here, we can make ZeroMQ::Raw independent
     # of ZeroMQ while keeping the dist name as ZeroMQ
-    XSLoader::load('ZeroMQ', '0.02_05');
+    XSLoader::load('ZeroMQ', '0.09_01');
 }
 
 our @EXPORT = qw(
@@ -33,6 +33,8 @@ our @EXPORT = qw(
     zmq_socket
 
     zmq_poll
+
+    zmq_device
 );
 
 1;
@@ -106,4 +108,6 @@ Callback that gets invoked. Takes no arguments.
 
 =back
 
+=head2 zmq_device( device, insocket, outsocket )
+
 =cut
